@@ -97,22 +97,25 @@ def main():
     parser.add_argument("-ver", "--version", action="version", version=__version__)
     FLAGS, unparsed = parser.parse_known_args()
 
-    from aeneas.language import Language
+    from subaligner.utils import Utils
     if FLAGS.languages:
-        for line in Language.CODE_TO_HUMAN_LIST:
-            print(line.replace("\t", "  "))
+        print("\n".join(Utils.get_language_table()))
         sys.exit(0)
     if FLAGS.video_path == "":
         print("--video_path was not passed in")
+        parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path == "":
         print("--subtitle_path was not passed in")
+        parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path.lower().startswith("http") and FLAGS.output == "":
         print("--output was not passed in for alignment on a remote subtitle file")
+        parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path.lower().startswith("teletext:") and FLAGS.output == "":
         print("--output was not passed in for alignment on embedded subtitles")
+        parser.print_usage()
         sys.exit(21)
 
     local_video_path = FLAGS.video_path
@@ -125,7 +128,6 @@ def main():
     from subaligner.translator import Translator
     from subaligner.exception import UnsupportedFormatException
     from subaligner.exception import TerminalException
-    from subaligner.utils import Utils
 
     try:
         if FLAGS.video_path.lower().startswith("http"):
@@ -153,6 +155,7 @@ def main():
                     Utils.extract_matroska_subtitle(local_video_path, int(params["stream_index"]), local_subtitle_path)
             else:
                 print("Embedded subtitle selector cannot be empty")
+                parser.print_usage()
                 sys.exit(21)
 
         predictor = Predictor()
