@@ -81,13 +81,13 @@ def main():
         action="store_true",
         help="Switch off stretch on subtitles for non-English speech",
     )
-    from aeneas.language import Language
+    from subaligner.utils import Utils
     parser.add_argument(
         "-sil",
         "--stretch_in_language",
         type=str,
-        choices=Language.ALLOWED_VALUES,
-        default=Language.ENG,
+        choices=Utils.get_stretch_language_codes(),
+        default="eng",
         help="Stretch the subtitle with the supported ISO 639-3 language code [https://en.wikipedia.org/wiki/List_of_ISO_639-3_codes].\nNB: This will be ignored if either -so or --stretch_off is present",
     )
     parser.add_argument(
@@ -126,20 +126,23 @@ def main():
     FLAGS, unparsed = parser.parse_known_args()
 
     if FLAGS.languages:
-        for line in Language.CODE_TO_HUMAN_LIST:
-            print(line.replace("\t", "  "))
+        print("\n".join(Utils.get_language_table()))
         sys.exit(0)
     if FLAGS.video_path == "":
         print("--video_path was not passed in")
+        parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path == "":
         print("--subtitle_path was not passed in")
+        parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path.lower().startswith("http") and FLAGS.output == "":
         print("--output was not passed in for alignment on a remote subtitle file")
+        parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path.lower().startswith("teletext:") and FLAGS.output == "":
         print("--output was not passed in for alignment on embedded subtitles")
+        parser.print_usage()
         sys.exit(21)
 
     local_video_path = FLAGS.video_path
@@ -155,7 +158,6 @@ def main():
     from subaligner.translator import Translator
     from subaligner.exception import UnsupportedFormatException
     from subaligner.exception import TerminalException
-    from subaligner.utils import Utils
 
     try:
         if FLAGS.video_path.lower().startswith("http"):
@@ -183,6 +185,7 @@ def main():
                     Utils.extract_matroska_subtitle(local_video_path, int(params["stream_index"]), local_subtitle_path)
             else:
                 print("Embedded subtitle selector cannot be empty")
+                parser.print_usage()
                 sys.exit(21)
 
         predictor = Predictor()
