@@ -35,8 +35,11 @@ class Subtitle(object):
     TMP_EXTENSIONS = [".tmp"]
     SAMI_EXTENSIONS = [".smi", ".sami"]
     STL_EXTENSIONS = [".stl"]
+    SCC_EXTENSIONS = [".scc"]
+    SBV_EXTENSIONS = [".sbv"]
+    YT_TRANSCRIPT_EXTENSIONS = [".ytt"]
 
-    def __init__(self, secret: object, subtitle_file_path: str, subtitle_format: str):
+    def __init__(self, secret: object, subtitle_file_path: str, subtitle_format: str) -> None:
         """Subtitle object initialiser.
 
         Arguments:
@@ -74,6 +77,12 @@ class Subtitle(object):
             self.__subs = self.__convert_sami_to_subs(subtitle_file_path)
         elif subtitle_format == "stl":
             self.__subs = self.__convert_stl_to_subs(subtitle_file_path)
+        elif subtitle_format == "scc":
+            self.__subs = self.__convert_scc_to_subs(subtitle_file_path)
+        elif subtitle_format == "sbv":
+            self.__subs = self.__convert_sbv_to_subs(subtitle_file_path)
+        elif subtitle_format == "ytt":
+            self.__subs = self.__convert_ytt_to_subs(subtitle_file_path)
         else:
             raise UnsupportedFormatException(
                 "Unknown subtitle format for file: {}".format(subtitle_file_path)
@@ -213,6 +222,45 @@ class Subtitle(object):
 
         return cls(cls.__secret, subtitle_file_path, "stl")
 
+    @classmethod
+    def load_scc(cls, subtitle_file_path: str) -> "Subtitle":
+        """Load a Scenarist Closed Caption subtitle file.
+
+        Arguments:
+            subtitle_file_path {string} -- The path to the subtitle file.
+
+        Returns:
+            Subtitle -- Subtitle object.
+        """
+
+        return cls(cls.__secret, subtitle_file_path, "scc")
+
+    @classmethod
+    def load_sbv(cls, subtitle_file_path: str) -> "Subtitle":
+        """Load a SubViewer subtitle file.
+
+        Arguments:
+            subtitle_file_path {string} -- The path to the subtitle file.
+
+        Returns:
+            Subtitle -- Subtitle object.
+        """
+
+        return cls(cls.__secret, subtitle_file_path, "sbv")
+
+    @classmethod
+    def load_ytt(cls, subtitle_file_path: str) -> "Subtitle":
+        """Load a YouTube transcript subtitle file.
+
+        Arguments:
+            subtitle_file_path {string} -- The path to the subtitle file.
+
+        Returns:
+            Subtitle -- Subtitle object.
+        """
+
+        return cls(cls.__secret, subtitle_file_path, "ytt")
+
     @classmethod
     def load(cls, subtitle_file_path: str) -> "Subtitle":
         """Load a SubRip or TTML subtitle file based on the file extension.
@@ -245,6 +293,12 @@ class Subtitle(object):
             return cls(cls.__secret, subtitle_file_path, "sami")
         elif file_extension in cls.STL_EXTENSIONS:
             return cls(cls.__secret, subtitle_file_path, "stl")
+        elif file_extension in cls.SCC_EXTENSIONS:
+            return cls(cls.__secret, subtitle_file_path, "scc")
+        elif file_extension in cls.SBV_EXTENSIONS:
+            return cls(cls.__secret, subtitle_file_path, "sbv")
+        elif file_extension in cls.YT_TRANSCRIPT_EXTENSIONS:
+            return cls(cls.__secret, subtitle_file_path, "ytt")
         else:
             return cls(cls.__secret, subtitle_file_path, "unknown")
 
@@ -306,6 +360,12 @@ class Subtitle(object):
                 subs = cls(cls.__secret, subtitle_file_path, "tmp").subs
             elif file_extension.lower() in cls.SAMI_EXTENSIONS:
                 subs = cls(cls.__secret, subtitle_file_path, "sami").subs
+            elif file_extension.lower() in cls.SCC_EXTENSIONS:
+                subs = cls(cls.__secret, subtitle_file_path, "scc").subs
+            elif file_extension.lower() in cls.SBV_EXTENSIONS:
+                subs = cls(cls.__secret, subtitle_file_path, "sbv").subs
+            elif file_extension.lower() in cls.YT_TRANSCRIPT_EXTENSIONS:
+                subs = cls(cls.__secret, subtitle_file_path, "ytt").subs
             else:
                 raise UnsupportedFormatException(
                     "Unknown subtitle format for file: {}".format(subtitle_file_path)
@@ -315,7 +375,7 @@ class Subtitle(object):
         return shifted_subtitle_file_path
 
     @staticmethod
-    def save_subs_as_target_format(subs: List[SubRipItem], source_file_path: str, target_file_path: str, frame_rate: Optional[float] = None) -> None:
+    def save_subs_as_target_format(subs: List[SubRipItem], source_file_path: str, target_file_path: str, frame_rate: Optional[float] = None, encoding: Optional[str] = None) -> None:
         """Save SubRipItems with the format determined by the target file extension.
 
         Arguments:
@@ -323,14 +383,15 @@ class Subtitle(object):
             source_file_path {string} -- The path to the original subtitle file.
             target_file_path {string} -- The path to the output subtitle file.
             frame_rate {float} -- The frame rate used by conversion to formats such as MicroDVD
+            encoding {str} -- The encoding of the exported output file {default: None}.
         """
 
-        encoding = Utils.detect_encoding(source_file_path)
+        encoding = Utils.detect_encoding(source_file_path) if encoding is None else encoding
         _, file_extension = os.path.splitext(target_file_path.lower())
         Subtitle.__save_subtitle_by_extension(file_extension, subs, source_file_path, target_file_path, encoding, frame_rate)
 
     @staticmethod
-    def export_subtitle(source_file_path: str, subs: List[SubRipItem], target_file_path: str, frame_rate: float = 25.0) -> None:
+    def export_subtitle(source_file_path: str, subs: List[SubRipItem], target_file_path: str, frame_rate: float = 25.0, encoding: Optional[str] = None) -> None:
         """Export subtitle in the format determined by the file extension.
 
         Arguments:
@@ -338,9 +399,10 @@ class Subtitle(object):
             subs {list} -- A list of SubRipItems.
             target_file_path {string} -- The path to the exported subtitle file.
             frame_rate {float} -- The frame rate for frame-based subtitle formats {default: 25.0}.
+            encoding {str} -- The encoding of the exported subtitle file {default: None}.
         """
 
-        encoding = Utils.detect_encoding(source_file_path)
+        encoding = Utils.detect_encoding(source_file_path) if encoding is None else encoding
         _, file_extension = os.path.splitext(source_file_path.lower())
         Subtitle.__save_subtitle_by_extension(file_extension, subs, source_file_path, target_file_path, encoding, frame_rate, is_exporting=True)
 
@@ -403,7 +465,7 @@ class Subtitle(object):
         """
 
         subs = Subtitle.load(subtitle_file_path).subs
-        texts = [sub.text for sub in subs]
+        texts = [sub.text.replace("\r\n", " ").replace("\n", " ").replace("\r", " ") for sub in subs]
         return delimiter.join(texts)
 
     @staticmethod
@@ -416,7 +478,8 @@ class Subtitle(object):
         return set(Subtitle.SUBRIP_EXTENTIONS + Subtitle.TTML_EXTENSIONS + Subtitle.WEBVTT_EXTENSIONS
                    + Subtitle.SSA_EXTENTIONS + Subtitle.ADVANCED_SSA_EXTENTIONS + Subtitle.MICRODVD_EXTENSIONS
                    + Subtitle.MPL2_EXTENSIONS + Subtitle.TMP_EXTENSIONS + Subtitle.SAMI_EXTENSIONS
-                   + Subtitle.STL_EXTENSIONS)
+                   + Subtitle.STL_EXTENSIONS + Subtitle.SCC_EXTENSIONS + Subtitle.SBV_EXTENSIONS
+                   + Subtitle.YT_TRANSCRIPT_EXTENSIONS)
 
     @property
     def subtitle_file_path(self) -> str:
@@ -587,6 +650,54 @@ class Subtitle(object):
 
         return Subtitle.__get_srt_subs(path, housekeep=True)
 
+    @staticmethod
+    def __convert_scc_to_subs(scc_file_path: str) -> SubRipFile:
+        """Convert a subtitle file from the SCC format to the SubRip format
+
+        Arguments:
+            scc_file_path {string} -- The path to the SCC subtitle file.
+
+        Returns:
+            {list} -- A list of SubRipItems.
+        """
+
+        _, path = tempfile.mkstemp()
+        Utils.scc2srt(scc_file_path, path)
+
+        return Subtitle.__get_srt_subs(path, housekeep=True)
+
+    @staticmethod
+    def __convert_sbv_to_subs(sbv_file_path: str) -> SubRipFile:
+        """Convert a subtitle file from the SubViewer format to the SubRip format
+
+        Arguments:
+            sbv_file_path {string} -- The path to the SubViewer subtitle file.
+
+        Returns:
+            {list} -- A list of SubRipItems.
+        """
+
+        _, path = tempfile.mkstemp()
+        Utils.sbv2srt(sbv_file_path, path)
+
+        return Subtitle.__get_srt_subs(path, housekeep=True)
+
+    @staticmethod
+    def __convert_ytt_to_subs(ytt_file_path: str) -> SubRipFile:
+        """Convert a subtitle file from the YouTube transcript format to the SubRip format
+
+        Arguments:
+            ytt_file_path {string} -- The path to the YouTube transcript subtitle file.
+
+        Returns:
+            {list} -- A list of SubRipItems.
+        """
+
+        _, path = tempfile.mkstemp()
+        Utils.ytt2srt(ytt_file_path, path)
+
+        return Subtitle.__get_srt_subs(path, housekeep=True)
+
     @staticmethod
     def __export_with_format(subs: List[SubRipItem], source_file_path: str, target_file_path: Optional[str], file_extension: str, suffix: str) -> None:
         if target_file_path is None:
@@ -699,6 +810,27 @@ class Subtitle(object):
                 SubRipFile(subs).save(target_file_path, encoding=encoding)
             finally:
                 os.remove(path)
+        elif file_extension in Subtitle.SCC_EXTENSIONS:
+            try:
+                _, path = tempfile.mkstemp()
+                SubRipFile(subs).save(path, encoding=encoding)
+                Utils.srt2scc(path, target_file_path)
+            finally:
+                os.remove(path)
+        elif file_extension in Subtitle.SBV_EXTENSIONS:
+            try:
+                _, path = tempfile.mkstemp()
+                SubRipFile(subs).save(path, encoding=encoding)
+                Utils.srt2sbv(path, target_file_path)
+            finally:
+                os.remove(path)
+        elif file_extension in Subtitle.YT_TRANSCRIPT_EXTENSIONS:
+            try:
+                _, path = tempfile.mkstemp()
+                SubRipFile(subs).save(path, encoding=encoding)
+                Utils.srt2ytt(path, target_file_path)
+            finally:
+                os.remove(path)
         else:
             raise UnsupportedFormatException(
                 "Unknown subtitle format for file: {}".format(source_file_path)
